@@ -38,7 +38,7 @@
 
 window_t *
 window_init(x, y, lines, columns)
-    int x, y, lines, columns;
+    size_t x, y, lines, columns;
 {
     window_t *this  = (window_t *)xmalloc(sizeof(window_t));
 
@@ -53,33 +53,32 @@ window_end(win)
     window_t *win;
 {
     if (win)
-	xfree(win);
+        xfree(win);
 }
 
 
 void
 window_resize(this, x, y, lines, columns)
     window_t *this;
-    int x, y;
-    int lines, columns;
+    size_t x, y, lines, columns;
 {
-    this->x	  = x;
-    this->y	  = y;
+    this->x       = x;
+    this->y       = y;
     this->lines   = lines;
     this->columns = columns;
 }
 
 
-int
+size_t
 window_write(str, length)
     char *str;
-    int length;
+    size_t length;
 {
     return tty_write(str, length);
 }
 
 
-int
+size_t
 window_putch(c)
     char c;
 {
@@ -90,7 +89,7 @@ window_putch(c)
 void
 window_cursormove_notify(this, y, x)
     window_t *this;
-    int y, x;
+    size_t y, x;
 {
     tty_cursormove_notify(y + this->y, x + this->x);
 }
@@ -99,7 +98,7 @@ window_cursormove_notify(this, y, x)
 void
 window_cursormove(this, y, x)
     window_t *this;
-    int y, x;
+    size_t y, x;
 {
     tty_cursormove(y + this->y, x + this->x);
 }
