@@ -23,24 +23,26 @@
 #define _GIT_WINDOW_H
 
 
+#include <sys/types.h>
+
 #include "stdc.h"
 
 
 typedef struct
 {
-    int lines, columns;
-    int x, y;
-    int cursorx, cursory;
+    size_t lines, columns;
+    size_t x, y;
+    size_t cursorx, cursory;
 } window_t;
 
 
-extern window_t *window_init __P((int, int, int, int));
+extern window_t *window_init __P((size_t, size_t, size_t, size_t));
 extern void      window_end __P((window_t *));
-extern void      window_resize __P((window_t *, int, int, int, int));
-extern int       window_write __P((char *, int));
-extern int       window_putch __P((char));
-extern void      window_cursormove_notify __P((window_t *, int, int));
-extern void      window_cursormove __P((window_t *, int, int));
+extern void      window_resize __P((window_t *,size_t,size_t,size_t,size_t));
+extern size_t    window_write __P((char *, size_t));
+extern size_t    window_putch __P((char));
+extern void      window_cursormove_notify __P((window_t *, size_t, size_t));
+extern void      window_cursormove __P((window_t *, size_t, size_t));
 
 
-#endif	/* _GIT_WINDOW_H */
+#endif  /* _GIT_WINDOW_H */
